@@ -8,11 +8,12 @@ def get_command_spec():
             {'name': 'data'},
             {'name': '--text', 'kwargs': {'action': 'store_true'}},
             {'name': '--hex', 'kwargs': {'action': 'store_true'}},
+            {'name': '--raw', 'kwargs': {'action': 'store_true'}},
         ],
     }
 
 
-def keccack_command(data, text, hex):
+def keccack_command(data, text, hex, raw):
     if text:
         hex = False
     elif hex:
@@ -24,5 +25,11 @@ def keccack_command(data, text, hex):
         keccak = binary.keccak(data)
     else:
         keccak = binary.keccak_text(data)
+
+    if raw:
+        if not keccak.startswith('0x'):
+            raise Exception('wrong format')
+        keccak = keccak[2:]
+
     print(keccak)
 
