@@ -1,13 +1,15 @@
+import pytest
+
 from ctc import directory
 from ctc.protocols import fei_utils
 
 
-def test_get_deposits_for_token():
+@pytest.mark.asyncio
+async def test_get_tokens_deposits():
 
-    deposits = fei_utils.get_deposits_for_token(
-        token=directory.token_addresses['DPI'],
+    deposits = await fei_utils.async_get_token_deposits(
+        directory.get_erc20_address('DPI'),
         block=13570382,
-        wrapper=False,
     )
     assert deposits == (
         '0x60b63ef8f461355207fe1d8102dda938bbd8c3fb',
@@ -16,18 +18,20 @@ def test_get_deposits_for_token():
     )
 
 
-def test_get_deposit_token_balance():
+@pytest.mark.asyncio
+async def test_get_deposit_token_balance():
 
-    balance = fei_utils.get_deposit_token_balance(
-        deposit_address='0x60b63ef8f461355207fe1d8102dda938bbd8c3fb',
+    balance = await fei_utils.async_get_deposit_balance(
+        '0x60b63ef8f461355207fe1d8102dda938bbd8c3fb',
         block=13570382,
     )
 
     assert balance == 154408399224631216120
 
 
-def test_get_tokens_in_pcv():
-    tokens = fei_utils.get_tokens_in_pcv(block=13570382, wrapper=False)
+@pytest.mark.asyncio
+async def test_get_tokens_in_pcv():
+    tokens = await fei_utils.async_get_tokens_in_pcv(block=13570382, wrapper=False)
     assert tokens == (
         '0x1111111111111111111111111111111111111111',
         '0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2',
@@ -38,8 +42,9 @@ def test_get_tokens_in_pcv():
     )
 
 
-def test_token_to_oracle():
-    oracle = fei_utils.token_to_oracle(
+@pytest.mark.asyncio
+async def test_token_to_oracle():
+    oracle = await fei_utils.async_get_token_oracle(
         '0x6b175474e89094c44da98b954eedeac495271d0f',
         block=13570382,
     )
